'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _util = require('util');

var _fastMemoize = require('fast-memoize');

var _fastMemoize2 = _interopRequireDefault(_fastMemoize);

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _postcssLoadConfig = require('postcss-load-config');

var _postcssLoadConfig2 = _interopRequireDefault(_postcssLoadConfig);

var _nodeSass = require('node-sass');

var _nodeSass2 = _interopRequireDefault(_nodeSass);

var _less = require('less');

var _less2 = _interopRequireDefault(_less);

var _stylus = require('stylus');

var _stylus2 = _interopRequireDefault(_stylus);

var _cssnano = require('cssnano');

var _cssnano2 = _interopRequireDefault(_cssnano);

var _postcssSorting = require('postcss-sorting');

var _postcssSorting2 = _interopRequireDefault(_postcssSorting);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const pSassRender = (0, _util.promisify)(_nodeSass2.default.render.bind(_nodeSass2.default));
const pLessRender = (0, _util.promisify)(_less2.default.render.bind(_less2.default));
const pStylusRender = (0, _util.promisify)(_stylus2.default.render.bind(_stylus2.default));

// ¯\_(ツ)_/¯ ...............
const compiler = {
  standardize: (0, _fastMemoize2.default)((() => {
    var _ref = _asyncToGenerator(function* (css) {
      const result = yield (0, _postcss2.default)([(0, _postcssSorting2.default)({
        'properties-order': 'alphabetical'
      }), _cssnano2.default]).process(css);

      return result.css;
    });

    return function (_x) {
      return _ref.apply(this, arguments);
    };
  })()),
  postcss: (0, _fastMemoize2.default)(
  // eslint-disable-next-line no-unused-vars
  (() => {
    var _ref2 = _asyncToGenerator(function* (filename, content, output, src) {
      const plugins = yield (0, _postcssLoadConfig2.default)({ env: process.env.NODE_ENV });
      const result = yield (0, _postcss2.default)(plugins).process(content, {
        from: filename,
        to: output
      });

      return {
        css: result.css,
        map: result.map
      };
    });

    return function (_x2, _x3, _x4, _x5) {
      return _ref2.apply(this, arguments);
    };
  })()),
  sass: (0, _fastMemoize2.default)(
  // eslint-disable-next-line no-unused-vars
  (() => {
    var _ref3 = _asyncToGenerator(function* (filename, content, output, src) {
      const result = yield pSassRender({
        data: content,
        outFile: output,
        includePaths: [_path2.default.dirname(filename)],
        sourceMap: true
      });

      return {
        css: result.css.toString(),
        map: result.map.toString()
      };
    });

    return function (_x6, _x7, _x8, _x9) {
      return _ref3.apply(this, arguments);
    };
  })()),
  '.scss': (0, _fastMemoize2.default)((() => {
    var _ref4 = _asyncToGenerator(function* (...args) {
      return compiler.sass.apply(null, args);
    });

    return function () {
      return _ref4.apply(this, arguments);
    };
  })()),
  '.sass': (0, _fastMemoize2.default)((() => {
    var _ref5 = _asyncToGenerator(function* (...args) {
      return compiler.sass.apply(null, args);
    });

    return function () {
      return _ref5.apply(this, arguments);
    };
  })()),
  less: (0, _fastMemoize2.default)(
  // eslint-disable-next-line no-unused-vars
  (() => {
    var _ref6 = _asyncToGenerator(function* (filename, content, output, src) {
      const result = yield pLessRender(content, {
        paths: [_path2.default.dirname(filename)],
        filename: _path2.default.basename(filename)
      });

      return {
        css: result.css
      };
    });

    return function (_x10, _x11, _x12, _x13) {
      return _ref6.apply(this, arguments);
    };
  })()),
  '.less': (0, _fastMemoize2.default)((() => {
    var _ref7 = _asyncToGenerator(function* (...args) {
      return compiler.less.apply(null, args);
    });

    return function () {
      return _ref7.apply(this, arguments);
    };
  })()),
  stylus: (0, _fastMemoize2.default)(
  // eslint-disable-next-line no-unused-vars
  (() => {
    var _ref8 = _asyncToGenerator(function* (filename, content, output, src) {
      const css = yield pStylusRender(content, {
        paths: [_path2.default.dirname(filename)]
      });

      return {
        css
      };
    });

    return function (_x14, _x15, _x16, _x17) {
      return _ref8.apply(this, arguments);
    };
  })()),
  '.styl': (0, _fastMemoize2.default)((() => {
    var _ref9 = _asyncToGenerator(function* (...args) {
      return compiler.stylus.apply(null, args);
    });

    return function () {
      return _ref9.apply(this, arguments);
    };
  })()),
  css: (0, _fastMemoize2.default)((() => {
    var _ref10 = _asyncToGenerator(function* (filename, content) {
      return {
        css: content
      };
    });

    return function (_x18, _x19) {
      return _ref10.apply(this, arguments);
    };
  })()),
  '.css': (0, _fastMemoize2.default)((() => {
    var _ref11 = _asyncToGenerator(function* (...args) {
      return compiler.css.apply(null, args);
    });

    return function () {
      return _ref11.apply(this, arguments);
    };
  })())
};

exports.default = compiler;
module.exports = exports['default'];