'use strict';

var _ = require('.');

var _2 = _interopRequireDefault(_);

var _compiler = require('./compiler');

var _compiler2 = _interopRequireDefault(_compiler);

var _section = require('./section');

var _section2 = _interopRequireDefault(_section);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

describe('Yosuga', () => {
  let yosuga;

  beforeEach(() => {
    yosuga = new _2.default({
      base: `${__dirname}/fixtures/targets`,
      main: 'sass'
    });
  });

  afterEach(() => {
    yosuga = undefined;
  });

  test('instance._getTargets', _asyncToGenerator(function* () {
    const targets = yield yosuga._getTargets();

    expect(targets).toMatchObject(['css', 'sass', 'less']);
  }));

  test('instance._getTargetContents', _asyncToGenerator(function* () {
    const results = yield yosuga._getTargetContents(_compiler2.default, ['css', 'sass']);

    expect(results).toHaveProperty('css');
    expect(results.css).toHaveProperty('button');
    expect(results.css).toHaveProperty('invalid');
    expect(results).toHaveProperty('sass');
    expect(results.sass).toHaveProperty('button');
    expect(results.sass).toHaveProperty('invalid');
    expect(results.sass['button.yosuga']).toEqual(undefined);
  }));

  test('instance._getTargetContents throw', _asyncToGenerator(function* () {
    yield expect(yosuga._getTargetContents(_compiler2.default, ['css', 'sass', 'less'])).rejects.toEqual(expect.stringMatching(/ERR!/));
  }));

  test('instance._getComparisonBy', () => {
    const items = {
      css: {
        button: {
          code: '',
          comparison: {
            css: 'button: {color:orange}'
          }
        }
      },
      sass: {
        button: {
          code: '',
          comparison: {
            css: 'button: {color:orange}'
          }
        }
      },
      postcss: {
        button: {
          code: '',
          comparison: {
            css: 'button: {color:orange}'
          }
        }
      }
    };

    const result = yosuga._getComparisonBy(items, 'button');
    expect(result.length).toEqual(3);
    expect(result[0]).toHaveProperty('css');
    expect(result[1]).toHaveProperty('css');
    expect(result[2]).toHaveProperty('css');
  });

  test('instance._diff', () => {
    const result = yosuga._diff([{
      css: 'body{color:orange}',
      target: 'css'
    }, {
      css: 'body{color:orange}',
      target: 'sass'
    }, {
      css: 'body{color:orange}',
      target: 'less'
    }], 'test');

    expect(result).toEqual(true);
  });

  test('instance._getSections', _asyncToGenerator(function* () {
    const result = yield yosuga._getSections(['button', 'invalid']);

    expect(result.length).toEqual(2);
    expect(result[0]).toBeInstanceOf(_section2.default);
    expect(result[0].title).toEqual('Button');
    expect(result[1].title).toEqual('Invalid');

    yield expect(yosuga._getSections(['button', 'invalid', 'foooo'])).rejects.toEqual(expect.stringMatching(/foooo\.html was not found/));
  }));
});